#pragma interface
#ifndef UUCP_H
#define UUCP_H

#ifndef MODULE_H
	#include <module.h>
#endif

class MODULE_UUCP: public LINUXCONF_MODULE{
	/*~PROTOBEG~ MODULE_UUCP */
public:
	MODULE_UUCP (void);
	int domenu (MENU_CONTEXT context, const char *key);
	int execmain (int argc, char *argv[], bool);
	void setmenu (DIALOG&dia, MENU_CONTEXT context);
	/*~PROTOEND~ MODULE_UUCP */
};


#include "uucp.p"

#endif

